@@ -10,10 +10,9 @@ class eitc_phase_out_start(Variable):
     definition_period = YEAR
 
     def formula(tax_unit, period, parameters):
-        num_children = tax_unit("eitc_child_count", period)
+        count_children = tax_unit("eitc_child_count", period)
         eitc = parameters(period).gov.irs.credits.eitc
         is_joint = tax_unit("tax_unit_is_joint", period)
-        return (
-            eitc.phase_out.start.calc(num_children)
-            + is_joint * eitc.phase_out.joint_bonus
-        )
+        joint_bonus = eitc.phase_out.joint_bonus.calc(count_children)
+        phase_out_start = eitc.phase_out.start.calc(count_children)
+        return phase_out_start + is_joint * joint_bonus
